==> haskell-comonad-5.0.4-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-8lc13BxmsJdJWnAIQnOnYu
key: comonad-5.0.4-8lc13BxmsJdJWnAIQnOnYu
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: b0382dc2b4565a0d80e5df0557fcccdc
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-8lc13BxmsJdJWnAIQnOnYu
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    distributive-0.6-5OBZ75aRqVqHcaenCFzKg2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=e9f0d327bd08c2672bd55840cd3b39db
             distributive-0.6-5OBZ75aRqVqHcaenCFzKg2=19b56766a8c59e7c88ca8cd39dc5b42c
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.4-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ
key: comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 33f3aad5ccd0483535d25476e9626028
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    distributive-0.6-2KZpFXarf2vK5nBSXPMPgm
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=e9f0d327bd08c2672bd55840cd3b39db
             distributive-0.6-2KZpFXarf2vK5nBSXPMPgm=4365458f993e4724719abaae53d87603
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
